==> blesta-5.10.2.zip: blesta/language/tr_tr/currencies.php <==
<?php
/**
 * Currencies
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Currencies.!error.processor.empty'] = 'Herhangi bir döviz kuru işlemcisi belirlenmemiştir.';
$lang['Currencies.!error.processor.invalid'] = 'Geçersiz döviz kuru işlemcisi.';
$lang['Currencies.!error.currency_code.is_default'] = '1$s para birimi varsayılan para birimidir ve silinemez.';
$lang['Currencies.!error.currency_code.in_use'] = '1$s para birimi şu anda kullanımda ve silinemez.';
$lang['Currencies.!error.exchange_updated.format'] = 'Borsa güncellenme tarihi geçersiz bir tarih biçimindedir.';
$lang['Currencies.!error.exchange_rate.format'] = 'Döviz kuru bir sayı olmalıdır.';
$lang['Currencies.!error.suffix.length'] = 'Para birimi sonekinin uzunluğu 10 karakteri geçemez.';
$lang['Currencies.!error.prefix.length'] = 'Para birimi önekinin uzunluğu 10 karakteri geçemez.';
$lang['Currencies.!error.precision.format'] = 'Para birimi hassasiyeti 0 ile 4 arasında bir sayı olmalıdır.';
$lang['Currencies.!error.format.format'] = 'Geçersiz para birimi biçimi.';
$lang['Currencies.!error.company_id.exists'] = 'Geçersiz şirket kimliği.';
$lang['Currencies.!error.code.exists'] = '1$s kodlu ve %2$s şirket kimliğine sahip bir para birimi zaten alınmış.';
$lang['Currencies.!error.code.length'] = 'Para birimi kodu ISO 4217\'de tanımlandığı gibi 3 alfa karakterden oluşmalıdır.';

==> blesta-5.11.4.zip: blesta/language/tr_tr/currencies.php <==
<?php
/**
 * Currencies
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Currencies.!error.processor.empty'] = 'Herhangi bir döviz kuru işlemcisi belirlenmemiştir.';
$lang['Currencies.!error.processor.invalid'] = 'Geçersiz döviz kuru işlemcisi.';
$lang['Currencies.!error.exchange_updated.format'] = 'Borsa güncellenme tarihi geçersiz bir tarih biçimindedir.';
$lang['Currencies.!error.exchange_rate.format'] = 'Döviz kuru bir sayı olmalıdır.';
$lang['Currencies.!error.suffix.length'] = 'Para birimi sonekinin uzunluğu 10 karakteri geçemez.';
$lang['Currencies.!error.prefix.length'] = 'Para birimi önekinin uzunluğu 10 karakteri geçemez.';
$lang['Currencies.!error.precision.format'] = 'Para birimi hassasiyeti 0 ile 4 arasında bir sayı olmalıdır.';
$lang['Currencies.!error.format.format'] = 'Geçersiz para birimi biçimi.';
$lang['Currencies.!error.company_id.exists'] = 'Geçersiz şirket kimliği.';
$lang['Currencies.!error.code.length'] = 'Para birimi kodu ISO 4217\'de tanımlandığı gibi 3 alfa karakterden oluşmalıdır.';
$lang['Currencies.!error.currency_code.is_default'] = 'Para birimi %1$s varsayılan para birimidir ve silinemez.';
$lang['Currencies.!error.currency_code.in_use'] = 'Para birimi %1$s şu anda kullanımda ve silinemez.';
$lang['Currencies.!error.code.exists'] = 'Kodu %1$s ve şirket kimliği %2$s olan bir para birimi zaten alınmış.';
